/***************************************************************************
                           routedialog.h
                           version 0.5.3 $Revision: 1.30 $
                           -------------------------------
    copyright            : (C) 1999-2003 by Stefan Preis
                         : (C) 2004-2008 by Guido Scholz
    email                : guido.scholz@bayernline.de
    last modified        : $Date: 2008-11-05 08:42:40 $
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
   this is the header file to routedialog.cpp
 ***************************************************************************/
#ifndef ROUTEDIALOG_H
#define ROUTEDIALOG_H

#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <QDialog>
#include <qlineedit.h>
#include <qlistview.h>
#include <qstring.h>
#include <qspinbox.h>
#include <QTreeWidgetItem>
#include <qvalidator.h>

#include "route.h"


// forward declaration
class element;

enum RouteType {
    kNormal = 0,
    kDetour,
    kHelp,
    kShunting,
    kShuntingD};


class RouteDialog: public QDialog
{
    Q_OBJECT

    element* startSignalElPtr;
    element* stopSignalElPtr;

    QTabWidget* tabWidget;
    QIntValidator* busValidator;
    QIntValidator* trainidValidator;
    QIntValidator* tracknumberValidator;

    QLineEdit*    routeNameLE;
    QLineEdit*    routeNumberLE;
    QLineEdit*    routeTrainLE;
    QLineEdit*    routeLengthLE;
    QLineEdit*    routeSpeedLimitLE;

    QLineEdit*    startSignalNameLE;
    QLineEdit*    entryTrackNumberLE;
    QLineEdit*    startSignalSrcpBusLE;
    QLineEdit*    startSignalAddressLE;
    QSpinBox*     startSignalStateSB;

    QLineEdit*    stopSignalNameLE;
    QLineEdit*    exitTrackNumberLE;
    QLineEdit*    stopSignalSrcpBusLE;
    QLineEdit*    stopSignalAddressLE;

    QCheckBox*    activatefbCB;
    QLabel*       activateSrcpBusLB;
    QLineEdit*    activateSrcpBusLE;
    QLabel*       activateContactLB;
    QSpinBox*     activateContactSB;
    QLabel*       activateModuleLB;
    QLineEdit*    activateModuleLE;
    QLabel*       activatePortLB;
    QLineEdit*    activatePortLE;

    QCheckBox*    releasefbCB;
    QLabel*       releaseSrcpBusLB;
    QLineEdit*    releaseSrcpBusLE;
    QLabel*       releaseContactLB;
    QSpinBox*     releaseContactSB;
    QLabel*       releaseModuleLB;
    QLineEdit*    releaseModuleLE;
    QLabel*       releasePortLB;
    QLineEdit*    releasePortLE;

    QButtonGroup* typeBG;
    QButtonGroup* activateRouteBG;
    QButtonGroup* releaseRouteBG;

    QGroupBox* activateRouteGB;
    QGroupBox* releaseRouteGB;

    QTreeWidget*  elementsLV;

    QPushButton*  upPB;
    QPushButton*  downPB;
    QPushButton*  editPB;
    QPushButton*  addPB;
    QPushButton*  removePB;

    void addIdentificationTab();
    void addElementsTab();
    void addRouteTypeTab();
    void addAutomaticTab();
    void updateEntrySignalName(int, int);
    void updateExitSignalName(int, int);
    void updateListIndexNumbersFrom(QTreeWidgetItem*);

public:
    RouteDialog(QWidget* parent = 0);
    void setRouteName(const QString&);
    void setRouteNumber(unsigned int);
    void setRouteTrain(unsigned int);
    void setRouteLength(unsigned int);
    void setRouteSpeedLimit(unsigned int);
    void setRouteType(int);
    void setEntrySignalData(const stateElement&);
    void setExitSignalData(const stateElement&);
    void setSignalTracks(unsigned int, unsigned int);
    void setActivateData(const PortState&);
    void setReleaseData(const PortState&);
    QString getRouteName();
    unsigned int getRouteNumber();
    unsigned int getRouteTrain();
    unsigned int getRouteLength();
    unsigned int getRouteSpeedLimit();
    void getEntrySignalData(stateElement&);
    void getExitSignalData(stateElement&);
    void getSignalTracks(unsigned int&, unsigned int&);
    void getActivateData(PortState&);
    void getReleaseData(PortState&);
    int getRouteType();
    void setRouteElements(const QList<stateElement*>&);
    void getRouteElements(QList<stateElement*>&);

private slots:
    void activateCBchanged(bool);
    void releaseCBchanged(bool);
    void activateContactSBChanged(int);
    void releaseContactSBChanged(int);
    void elementsLVChanged(QTreeWidgetItem*, QTreeWidgetItem*);
    void removeElementFromList();
    void startSignalBusChanged(const QString&);
    void startSignalAddressChanged(const QString&);
    void stopSignalBusChanged(const QString&);
    void stopSignalAddressChanged(const QString&);
    void upListElement();
    void downListElement();
    void editListElement();
    void addElementToList();

signals:
    void getElementByAddress(const int, const int, element**);

};

#endif    //ROUTEDIALOG_H
