/***************************************************************************
                           routelvi.cpp
                           version 0.5.3 $Revision: 1.10 $
                           -------------------------------
    copyright            : (C) 2007-2008 by Guido Scholz
    email                : guido.scholz@bayernline.de
    last modified        : $Date: 2008-11-05 08:42:40 $
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
   this code implements a listview item displaying route data
 ***************************************************************************/

#include "route.h"
#include "routelvi.h"

#include "pixmaps/route_locked.xpm"
#include "pixmaps/route_unlocked.xpm"
#include "pixmaps/route_wflock.xpm"
#include "pixmaps/route_wfunlock.xpm"


RouteLVI::RouteLVI(QTreeWidget* parent, Route* rt): QTreeWidgetItem(parent)
{
    // TODO: move pixmaps to parent
    pLocked = QPixmap(route_locked_xpm);
    pUnlocked = QPixmap(route_unlocked_xpm);
    pWfLock = QPixmap(route_wflock_xpm);
    pWfUnlock = QPixmap(route_wfunlock_xpm);

    route = rt;
    setTextAlignment(rlviEntryTrack, Qt::AlignRight);
    setTextAlignment(rlviExitTrack, Qt::AlignRight);
    setTextAlignment(rlviType, Qt::AlignCenter);
    setTextAlignment(rlviId, Qt::AlignRight);
    setTextAlignment(rlviTrain, Qt::AlignRight);
    setTextAlignment(rlviState, Qt::AlignRight);
    setTextAlignment(rlviLength, Qt::AlignRight);
    setTextAlignment(rlviLimit, Qt::AlignRight);
    updateRouteData();
}


/*
 * sort all columns:
 *
 * No  Name      Type
 * -------------------------------
 *  0  Name       QString
 *  1  From       QString
 *  2  To         QString
 *  3  Entry trk  unsigned int
 *  4  Exit trk   unsigned int
 *  5  Type       (int, int)/QString
 *  6  Id         unsigned int
 *  7  Train      unsigned int
 *  8  State      int
 *  9  Length     unsigned int
 * 10  Speedlimit unsigned int
 * -------------------------------
 */
bool RouteLVI::operator<(const QTreeWidgetItem& other) const
{
    if (route == NULL)
        return false;

    int column = treeWidget()->sortColumn();
    bool returnvalue = false;
    RouteLVI item = static_cast<const RouteLVI&>(other);

    switch (column) {
        case rlviEntryTrack:
            /* EntryTrack    unsigned int*/
            returnvalue = (route->getEntryTrack() <
                    item.getRouteEntryTrack());
            break;

        case rlviExitTrack:
            /* ExitTrack    unsigned int*/
            returnvalue = (route->getExitTrack() <
                    item.getRouteExitTrack());
            break;

        case rlviId:
            /* Id      unsigned int*/
            returnvalue = (route->getId() < item.getRouteId());
            break;

        case rlviTrain:
            /* Train   unsigned int*/
            returnvalue = (route->getTrain() < item.getRouteTrain());
            break;

        case rlviState:
            /* State    int*/
            returnvalue = (route->getState() < item.getRouteState());
            break;

        case rlviLength:
            /* Length   unsigned int*/
            returnvalue = (route->getLength() < item.getRouteLength());
            break;

        case rlviLimit:
            /* Speedlimit   unsigned int*/
            returnvalue = (route->getSpeedLimit() <
                    item.getRouteSpeedLimit());
            break;

        default:
            /* compare string values */
            returnvalue = (text(column).localeAwareCompare(
                        other.text(column)) < 0);
            break;
    }

    return returnvalue;
}


unsigned int RouteLVI::getRouteId()
{
    if (route == NULL)
        return 0;
    else
        return route->getId();
}


unsigned int RouteLVI::getRouteTrain()
{
    if (route == NULL)
        return 0;
    else
        return route->getTrain();
}


unsigned int RouteLVI::getRouteLength()
{
    if (route == NULL)
        return 0;
    else
        return route->getLength();
}


unsigned int RouteLVI::getRouteSpeedLimit()
{
    if (route == NULL)
        return 0;
    else
        return route->getSpeedLimit();
}


unsigned int RouteLVI::getRouteEntryTrack()
{
    if (route == NULL)
        return 0;
    else
        return route->getEntryTrack();
}


unsigned int RouteLVI::getRouteExitTrack()
{
    if (route == NULL)
        return 0;
    else
        return route->getExitTrack();
}


int RouteLVI::getRouteState()
{
    if (route == NULL)
        return 0;
    else
        return route->getState();
}


Route* RouteLVI::getRoute()
{
    return route;
}


void RouteLVI::setRoute(Route* rt)
{
    if (rt != route) {
        route = rt;
        updateRouteData();
    }
}


void RouteLVI::updateRouteData()
{
    if (route != NULL) {
        QString num;

        updateRouteStatePixmap();
        setText(rlviId, QString::number(route->getId()));
        setText(rlviName, route->getSectionName());
        setText(rlviFromSig, route->getFromSignalName());
        setText(rlviToSig, route->getToSignalName());
        setText(rlviType, route->getTypeStr());
        setText(rlviEntryTrack, QString::number(route->getEntryTrack()));
        setText(rlviExitTrack, QString::number(route->getExitTrack()));
        setText(rlviTrain, QString::number(route->getTrain()));
        setText(rlviState, QString::number(route->getState()));
        setText(rlviLength, QString::number(route->getLength()));
        setText(rlviLimit, QString::number(route->getSpeedLimit()));
    }
    else {
        setIcon(rlviId, pUnlocked);
        setText(rlviName, "");
        setText(rlviFromSig, "");
        setText(rlviToSig, "");
        setText(rlviType, "");
        setText(rlviEntryTrack, "");
        setText(rlviExitTrack, "");
        setText(rlviId, "");
        setText(rlviTrain, "");
        setText(rlviState, "");
        setText(rlviLength, "");
        setText(rlviLimit, "");
    }
}


void RouteLVI::updateRouteStatePixmap()
{
    if (route == NULL)
        return;

    int rs = route->getState();

    switch (rs) {
        case Route::rsUnlocked:
            setIcon(rlviId, pUnlocked);
            break;
        case Route::rsLocked:
            setIcon(rlviId, pLocked);
            break;
        case Route::rsWfLock:
            setIcon(rlviId, pWfLock);
            break;
        case Route::rsWfUnlock:
            setIcon(rlviId, pWfUnlock);
            break;
    }
}

